==> client-core-1.2.0-rc6.tgz: package/src/admin/components/Setting/Coil.tsx <==
import React, { useEffect } from 'react'
import { useTranslation } from 'react-i18next'

import InputText from '@etherealengine/client-core/src/common/components/InputText'
import Box from '@etherealengine/ui/src/Box'
import Grid from '@etherealengine/ui/src/Grid'
import Typography from '@etherealengine/ui/src/Typography'

import { useAuthState } from '../../../user/services/AuthService'
import { AdminCoilSettingService, useCoilSettingState } from '../../services/Setting/CoilSettingService'
import styles from '../../styles/settings.module.scss'

const Coil = () => {
  const { t } = useTranslation()
  const coilSettingState = useCoilSettingState()
  const [coil] = coilSettingState?.coil.value || []
  const authState = useAuthState()
  const user = authState.user

  useEffect(() => {
    if (user?.id?.value && coilSettingState?.updateNeeded?.value) {
      AdminCoilSettingService.fetchCoil()
    }
  }, [authState?.user?.id?.value, coilSettingState?.updateNeeded?.value])

  return (
    <Box>
      <Typography component="h1" className={styles.settingsHeading}>
        {t('admin:components.setting.coil')}
      </Typography>
      <Grid container spacing={3}>
        <Grid item xs={6} sm={6}>
          <InputText
            name="clientId"
            label={t('admin:components.setting.clientId')}
            value={coil?.clientId || ''}
            disabled
          />

          <InputText
            name="clientSecret"
            label={t('admin:components.setting.clientSecret')}
            value={coil?.clientSecret || ''}
            disabled
          />
        </Grid>
        <Grid item xs={6} sm={6}>
          <InputText
            name="paymentPointer"
            label={t('admin:components.setting.coilPaymentPointer')}
            value={coil?.paymentPointer || ''}
            disabled
          />
        </Grid>
      </Grid>
    </Box>
  )
}

export default Coil

==> client-core-1.2.1.tgz: package/src/admin/components/Setting/Coil.tsx <==
import React, { useEffect } from 'react'
import { useTranslation } from 'react-i18next'

import InputText from '@etherealengine/client-core/src/common/components/InputText'
import { getMutableState, useHookstate } from '@etherealengine/hyperflux'
import Box from '@etherealengine/ui/src/Box'
import Grid from '@etherealengine/ui/src/Grid'
import Typography from '@etherealengine/ui/src/Typography'

import { AuthState } from '../../../user/services/AuthService'
import { AdminCoilSettingService, AdminCoilSettingsState } from '../../services/Setting/CoilSettingService'
import styles from '../../styles/settings.module.scss'

const Coil = () => {
  const { t } = useTranslation()
  const coilSettingState = useHookstate(getMutableState(AdminCoilSettingsState))
  const [coil] = coilSettingState?.coil?.get({ noproxy: true }) || []

  const user = useHookstate(getMutableState(AuthState).user)

  useEffect(() => {
    if (user?.id?.value && coilSettingState?.updateNeeded?.value) {
      AdminCoilSettingService.fetchCoil()
    }
  }, [user?.id?.value, coilSettingState?.updateNeeded?.value])

  return (
    <Box>
      <Typography component="h1" className={styles.settingsHeading}>
        {t('admin:components.setting.coil')}
      </Typography>
      <Grid container spacing={3}>
        <Grid item xs={6} sm={6}>
          <InputText
            name="clientId"
            label={t('admin:components.setting.clientId')}
            value={coil?.clientId || ''}
            disabled
          />

          <InputText
            name="clientSecret"
            label={t('admin:components.setting.clientSecret')}
            value={coil?.clientSecret || ''}
            disabled
          />
        </Grid>
        <Grid item xs={6} sm={6}>
          <InputText
            name="paymentPointer"
            label={t('admin:components.setting.coilPaymentPointer')}
            value={coil?.paymentPointer || ''}
            disabled
          />
        </Grid>
      </Grid>
    </Box>
  )
}

export default Coil
